day110

package
v0.0.0-...-36687a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllPathsToLeaves

func AllPathsToLeaves(tree *IntBinaryTree) [][]int

AllPathsToLeaves return the nodes encountered from the root to each leave.

Types

type IntBinaryTree

type IntBinaryTree struct {
	Value       int
	Left, Right *IntBinaryTree
}

IntBinaryTree is a binary tree with values that are integers.

Jump to