day159

package
v0.0.0-...-36687a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ErrNoRecurringRune

func ErrNoRecurringRune() error

ErrNoRecurringRune is the error returned when the input has no recurring runes. Every rune is unique.

func FirstRecurringRune

func FirstRecurringRune(s string) (rune, error)

FirstRecurringRune returns the first rune that appears twice. If no rune is repeated, then an error is returned. Runs in O(N) time and potentially O(N) space.

Types

This section is empty.

Jump to