package
Version:
v0.0.0-...-36687a4
Opens a new window with list of versions in this module.
Published: Oct 28, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func StartingIndicies(str, pattern string) []int
StartingIndicies returns the starting indicies
of all occurrences of the pattern in the str.
Runs in O(N*K) time where N=len(str) and K=len(pattern).
Source Files
¶
Click to show internal directories.
Click to hide internal directories.