package
Version:
v0.0.0-...-36687a4
Opens a new window with list of versions in this module.
Published: Oct 28, 2020
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GhostWinningLetterPlayerOne(dict []string) []rune
GhostWinningLetterPlayerOne determine the letters the
first player should start with, such that with optimal
play they cannot lose.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.