Discover Packages
github.com/vaskoz/dailycodingproblem-go
day285
package
Version:
v0.0.0-...-36687a4
Opens a new window with list of versions in this module.
Published: Oct 28, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func SunsetViews(buildingHeights []int ) int
SunsetViews returns the number of building with some amount
of sunset views.
Buildings are ordered from east to west.
Runs in O(N) time and O(1) space.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.