day327

package
v0.0.0-...-36687a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BinaryTree

type BinaryTree struct {
	Val         int
	Left, Right *BinaryTree
}

BinaryTree is an integer binary tree.

func MergeBinaryTrees

func MergeBinaryTrees(one, two *BinaryTree) *BinaryTree

MergeBinaryTrees returns a new binary tree that is the "merge" of two other binary trees. Merge is defined as the sum of equivalently placed nodes. Runs in O(N) time.

Jump to