day352

package
v0.0.0-...-36687a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsValidCrossword

func IsValidCrossword(puzzle [][]Square) bool

IsValidCrossword returns true if the puzzle meets all the requirements of a crossword puzzle. This is a brute force approach.

Types

type Square

type Square int

Square represents either a white or black square on a crossword puzzle.

const (
	// W is a white square
	W Square = iota
	// B is a white square
	B
)

Jump to