day393

package
v0.0.0-...-36687a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LargestRangeBrute

func LargestRangeBrute(nums []int) (int, int)

LargestRangeBrute returns the largest range of integers using brute force. Runtime is O(N*K) where K is the length of the longest range. Effectively, this is O(N^2). Converts the input into a hash set.

func LargestRangeSort

func LargestRangeSort(nums []int) (int, int)

LargestRangeSort returns the largest range of integers using slightly better than brute-force. Runtime is O(N log N). Performs a copy to avoid mutating the input.

Types

This section is empty.

Jump to