day415

package
v0.0.0-...-36687a4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MaxProfitWithFee

func MaxProfitWithFee(prices []int, fee int) int

MaxProfitWithFee returns the maximum possible profit by making transactions where each one has a fee. A backtracking algorithm that tries all profitable paths looking for the most profitable.

Types

This section is empty.

Jump to