Discover Packages
github.com/vaskoz/dailycodingproblem-go
day416
package
Version:
v0.0.0-...-36687a4
Opens a new window with list of versions in this module.
Published: Oct 28, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
MinimumStepsPath returns the minimum number of steps required
to walk the path. The path must be walked in order.
8 directions possible: 4 cardinal and 4 intercardinal.
type Point struct {
X, Y int
}
Point is a X and Y coordinate.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.