package
Version:
v0.0.0-...-36687a4
Opens a new window with list of versions in this module.
Published: Oct 28, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
AskPolymorph queries the poly how it does it.
type Industrious struct {
}
Industrious can 'DoIt' in a productive way.
type Polymorph interface {
DoIt() string
}
Polymorph is a thing that can 'DoIt'
but specifics are based on implementation.
Sloth can 'DoIt' in a relaxed way.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.