Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AllPathsToLeaves ¶
func AllPathsToLeaves(tree *IntBinaryTree) [][]int
AllPathsToLeaves return the nodes encountered from the root to each leave.
Types ¶
type IntBinaryTree ¶
type IntBinaryTree struct {
Value int
Left, Right *IntBinaryTree
}
IntBinaryTree is a binary tree with values that are integers.
Click to show internal directories.
Click to hide internal directories.