Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ErrNoRecurringRune ¶
func ErrNoRecurringRune() error
ErrNoRecurringRune is the error returned when the input has no recurring runes. Every rune is unique.
func FirstRecurringRune ¶
FirstRecurringRune returns the first rune that appears twice. If no rune is repeated, then an error is returned. Runs in O(N) time and potentially O(N) space.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.