Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MostPlayerWins ¶
MostPlayerWins returns the most number of possible player wins. Dealer gets the first 2 cards of each hand. Player gets second 2 cards. Player tries every game based on drawing cards up until bust. Dealer draws until greater than or equal to 17 and stops.
Types ¶
Click to show internal directories.
Click to hide internal directories.