Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LargestRangeBrute ¶
LargestRangeBrute returns the largest range of integers using brute force. Runtime is O(N*K) where K is the length of the longest range. Effectively, this is O(N^2). Converts the input into a hash set.
func LargestRangeSort ¶
LargestRangeSort returns the largest range of integers using slightly better than brute-force. Runtime is O(N log N). Performs a copy to avoid mutating the input.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.